@@ -13,6 +13,9 @@ impl TypeId {
     pub const VAR_CHAR: TypeId = TypeId(253); // or VAR_BINARY
     pub const TEXT: TypeId = TypeId(252); // or BLOB
 
+    // Enum
+    pub const ENUM: TypeId = TypeId(247);
+
     // More Bytes
     pub const TINY_BLOB: TypeId = TypeId(249);
     pub const MEDIUM_BLOB: TypeId = TypeId(250);
@@ -23,10 +26,12 @@ impl TypeId {
     pub const SMALL_INT: TypeId = TypeId(2);
     pub const INT: TypeId = TypeId(3);
     pub const BIG_INT: TypeId = TypeId(8);
+    // pub const MEDIUM_INT: TypeId = TypeId(9);
 
     // Numeric: FLOAT, DOUBLE
     pub const FLOAT: TypeId = TypeId(4);
     pub const DOUBLE: TypeId = TypeId(5);
+    // pub const NEWDECIMAL: TypeId = TypeId(246);
 
     // Date/Time: DATE, TIME, DATETIME, TIMESTAMP
     pub const DATE: TypeId = TypeId(10);
