@@ -6,27 +6,27 @@ use std::{
     time::{Duration, Instant},
 };
 
-use crate::connection::{Connect, Connection};
+use crate::connection::Connect;
+use crate::database::Database;
 use crate::transaction::Transaction;
 
 use self::inner::SharedPool;
 use self::options::Options;
 
-pub use self::conn::PoolConnection;
-
-mod conn;
+mod connection;
 mod executor;
 mod inner;
 mod options;
 
+pub use self::connection::PoolConnection;
 pub use self::options::Builder;
 
 /// A pool of database connections.
-pub struct Pool<C>(Arc<SharedPool<C>>);
+pub struct Pool<C>(pub(crate) Arc<SharedPool<C>>);
 
 impl<C> Pool<C>
 where
-    C: Connection + Connect<Connection = C>,
+    C: Connect,
 {
     /// Creates a connection pool with the default configuration.
     ///
@@ -40,7 +40,7 @@ where
     }
 
     async fn with_options(url: &str, options: Options) -> crate::Result<Self> {
-        let inner = SharedPool::new_arc(url, options).await?;
+        let inner = SharedPool::<C>::new_arc(url, options).await?;
 
         Ok(Pool(inner))
     }
@@ -127,7 +127,7 @@ impl<C> Clone for Pool<C> {
 
 impl<C> fmt::Debug for Pool<C>
 where
-    C: Connection + Connect<Connection = C>,
+    C: Connect,
 {
     fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
         fmt.debug_struct("Pool")
@@ -143,18 +143,19 @@ where
 /// get the time between the deadline and now and use that as our timeout
 ///
 /// returns `Error::PoolTimedOut` if the deadline is in the past
-fn deadline_as_timeout(deadline: Instant) -> crate::Result<Duration> {
+fn deadline_as_timeout<DB: Database>(deadline: Instant) -> crate::Result<Duration> {
     deadline
         .checked_duration_since(Instant::now())
         .ok_or(crate::Error::PoolTimedOut(None))
 }
 
 #[test]
+#[allow(dead_code)]
 fn assert_pool_traits() {
     fn assert_send_sync<T: Send + Sync>() {}
     fn assert_clone<T: Clone>() {}
 
-    fn assert_pool<C: Connection + Connect<Connection = C>>() {
+    fn assert_pool<C: Connect>() {
         assert_send_sync::<Pool<C>>();
         assert_clone::<Pool<C>>();
     }
