@@ -1,24 +1,24 @@
-use super::Encode;
+use super::Write;
 use crate::io::BufMut;
 use crate::postgres::protocol::{StatementId, TypeFormat};
 use byteorder::{ByteOrder, NetworkEndian};
 
-pub struct Bind<'a> {
+pub(crate) struct Bind<'a> {
     /// The name of the destination portal (an empty string selects the unnamed portal).
-    pub portal: &'a str,
+    pub(crate) portal: &'a str,
 
     /// The id of the source prepared statement (0 selects the unnamed statement).
-    pub statement: StatementId,
+    pub(crate) statement: StatementId,
 
     /// The parameter format codes. Each must presently be zero (text) or one (binary).
     ///
     /// There can be zero to indicate that there are no parameters or that the parameters all use the
     /// default format (text); or one, in which case the specified format code is applied to all
     /// parameters; or it can equal the actual number of parameters.
-    pub formats: &'a [TypeFormat],
+    pub(crate) formats: &'a [TypeFormat],
 
-    pub values_len: i16,
-    pub values: &'a [u8],
+    pub(crate) values_len: i16,
+    pub(crate) values: &'a [u8],
 
     /// The result-column format codes. Each must presently be zero (text) or one (binary).
     ///
@@ -26,11 +26,11 @@ pub struct Bind<'a> {
     /// result columns should all use the default format (text); or one, in which
     /// case the specified format code is applied to all result columns (if any);
     /// or it can equal the actual number of result columns of the query.
-    pub result_formats: &'a [TypeFormat],
+    pub(crate) result_formats: &'a [TypeFormat],
 }
 
-impl Encode for Bind<'_> {
-    fn encode(&self, buf: &mut Vec<u8>) {
+impl Write for Bind<'_> {
+    fn write(&self, buf: &mut Vec<u8>) {
         buf.push(b'B');
 
         let pos = buf.len();
@@ -38,7 +38,7 @@ impl Encode for Bind<'_> {
 
         buf.put_str_nul(self.portal);
 
-        self.statement.encode(buf);
+        self.statement.write(buf);
 
         buf.put_i16::<NetworkEndian>(self.formats.len() as i16);
 
